@@ -370,7 +370,7 @@ impl Channel {
             m => {
                 error!("the client should not receive this method: {:?}", m);
                 self.handle_invalid_contents(
-                    format!("unexepcted method received on channel {}", self.id),
+                    format!("unexpected method received on channel {}", self.id),
                     m.get_amqp_class_id(),
                     m.get_amqp_method_id(),
                 )
@@ -533,10 +533,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted connection open-ok received on channel {}",
-                    self.id
+                    "unexpected connection open-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -624,10 +624,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted connection close-ok received on channel {}",
-                    self.id
+                    "unexpected connection close-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -727,20 +727,15 @@ impl Channel {
             return Err(Error::InvalidChannelState(self.status.state()));
         }
 
-        match self.frames.next_expected_reply(self.id) {
+        match self.frames.next_expected_reply(self.id){
             Some(Reply::ConnectionUpdateSecretOk(resolver)) => {
                 let res = Ok(());
                 resolver.swear(res.clone());
                 res
-            }
-            _ => self.handle_invalid_contents(
-                format!(
-                    "unexepcted connection update-secret-ok received on channel {}",
-                    self.id
-                ),
-                method.get_amqp_class_id(),
-                method.get_amqp_method_id(),
-            ),
+            },
+            unexpected => {
+                self.handle_invalid_contents(format!("unexpected connection update-secret-ok received on channel {}, was awaiting for {:?}", self.id, unexpected), method.get_amqp_class_id(), method.get_amqp_method_id())
+            },
         }
     }
     #[allow(clippy::too_many_arguments)]
@@ -782,8 +777,11 @@ impl Channel {
             Some(Reply::ChannelOpenOk(resolver, channel)) => {
                 self.on_channel_open_ok_received(method, resolver, channel)
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted channel open-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected channel open-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -856,8 +854,11 @@ impl Channel {
             Some(Reply::ChannelFlowOk(resolver)) => {
                 self.on_channel_flow_ok_received(method, resolver)
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted channel flow-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected channel flow-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -942,10 +943,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted channel close-ok received on channel {}",
-                    self.id
+                    "unexpected channel close-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1006,10 +1007,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted access request-ok received on channel {}",
-                    self.id
+                    "unexpected access request-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1101,10 +1102,10 @@ impl Channel {
                 options,
                 creation_arguments,
             ),
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted exchange declare-ok received on channel {}",
-                    self.id
+                    "unexpected exchange declare-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1162,10 +1163,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted exchange delete-ok received on channel {}",
-                    self.id
+                    "unexpected exchange delete-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1249,10 +1250,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted exchange bind-ok received on channel {}",
-                    self.id
+                    "unexpected exchange bind-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1336,10 +1337,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted exchange unbind-ok received on channel {}",
-                    self.id
+                    "unexpected exchange unbind-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1415,10 +1416,10 @@ impl Channel {
             Some(Reply::QueueDeclareOk(resolver, options, creation_arguments)) => {
                 self.on_queue_declare_ok_received(method, resolver, options, creation_arguments)
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted queue declare-ok received on channel {}",
-                    self.id
+                    "unexpected queue declare-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1500,8 +1501,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted queue bind-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected queue bind-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -1549,8 +1553,11 @@ impl Channel {
             Some(Reply::QueuePurgeOk(resolver)) => {
                 self.on_queue_purge_ok_received(method, resolver)
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted queue purge-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected queue purge-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -1613,8 +1620,11 @@ impl Channel {
             Some(Reply::QueueDeleteOk(resolver, queue)) => {
                 self.on_queue_delete_ok_received(method, resolver, queue)
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted queue delete-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected queue delete-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -1688,8 +1698,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted queue unbind-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected queue unbind-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -1737,8 +1750,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted basic qos-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected basic qos-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -1833,10 +1849,10 @@ impl Channel {
                 creation_arguments,
                 original,
             ),
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted basic consume-ok received on channel {}",
-                    self.id
+                    "unexpected basic consume-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -1921,8 +1937,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted basic cancel-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected basic cancel-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -2023,8 +2042,11 @@ impl Channel {
             Some(Reply::BasicGetOk(resolver, queue, options)) => {
                 self.on_basic_get_ok_received(method, resolver, queue, options)
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted basic get-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected basic get-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -2156,10 +2178,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted basic recover-ok received on channel {}",
-                    self.id
+                    "unexpected basic recover-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
@@ -2235,8 +2257,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted tx select-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected tx select-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -2279,8 +2304,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted tx commit-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected tx commit-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -2325,8 +2353,11 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
-                format!("unexepcted tx rollback-ok received on channel {}", self.id),
+            unexpected => self.handle_invalid_contents(
+                format!(
+                    "unexpected tx rollback-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
+                ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
             ),
@@ -2372,10 +2403,10 @@ impl Channel {
                 resolver.swear(res.clone());
                 res
             }
-            _ => self.handle_invalid_contents(
+            unexpected => self.handle_invalid_contents(
                 format!(
-                    "unexepcted confirm select-ok received on channel {}",
-                    self.id
+                    "unexpected confirm select-ok received on channel {}, was awaiting for {:?}",
+                    self.id, unexpected
                 ),
                 method.get_amqp_class_id(),
                 method.get_amqp_method_id(),
